@@ -7,7 +7,7 @@
  *
  * This file is placed under the LGPL.
  *
- * $Id: tslib-private.h,v 1.3 2004/07/21 19:12:59 dlowder Exp $
+ * $Id: tslib-private.h,v 1.2 2002/06/17 17:21:43 dlowder Exp $
  *
  * Internal touch screen library definitions.
  */
@@ -21,15 +21,10 @@ extern "C" {
 struct tsdev {
 	int fd;
 	struct tslib_module_info *list;
-	struct tslib_module_info *list_raw; /* points to position in 'list' where raw reads
-					       come from.  default is the position of the
-					       ts_read_raw module. */
 };
 
 int __ts_attach(struct tsdev *ts, struct tslib_module_info *info);
-int __ts_attach_raw(struct tsdev *ts, struct tslib_module_info *info);
 int ts_load_module(struct tsdev *dev, const char *module, const char *params);
-int ts_load_module_raw(struct tsdev *dev, const char *module, const char *params);
 int ts_error(const char *fmt, ...);
 
 #ifdef __cplusplus
